@@ -16,7 +16,7 @@ use core::marker::PhantomData;
 
 #[cfg(feature = "serde_support")]
 use serde::{
-  de::{Error, SeqAccess, Visitor},
+  de::{SeqAccess, Visitor},
   Deserialize, Deserializer, Serialize, Serializer,
 };
 
@@ -538,6 +538,7 @@ impl<const N: usize> Write for StaticVec<u8, {N}> {
 #[cfg(feature = "serde_support")]
 impl<'de, T, const N: usize> Deserialize<'de> for StaticVec<T, {N}>
 where T: Deserialize<'de> {
+  #[inline]
   fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
   where D: Deserializer<'de> {
     struct StaticVecVisitor<'de, T, const N: usize>(PhantomData<(&'de (), T)>);
@@ -546,22 +547,25 @@ where T: Deserialize<'de> {
     where T: Deserialize<'de> {
       type Value = StaticVec<T, {N}>;
 
+      #[inline(always)]
       fn expecting(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
         write!(formatter, "no more than {} items", N)
       }
 
+      #[inline]
       fn visit_seq<SA>(self, mut seq: SA) -> Result<Self::Value, SA::Error>
       where SA: SeqAccess<'de> {
-        let mut vec = StaticVec::<T, {N}>::new();
-        while let Some(value) = seq.next_element()? {
-          if vec.len() == N {
-            return Err(SA::Error::invalid_length(N + 1, &self));
-          }
-          unsafe {
-            vec.push_unchecked(value);
+        let mut res = StaticVec::<T, {N}>::new();
+        while res.length < N {
+          if let Some(val) = seq.next_element()? {
+            unsafe {
+              res.push_unchecked(val);
+            }
+          } else {
+            break;
           }
         }
-        Ok(vec)
+        Ok(res)
       }
     }
     deserializer.deserialize_seq(StaticVecVisitor::<T, {N}>(PhantomData))
@@ -571,6 +575,7 @@ where T: Deserialize<'de> {
 #[cfg(feature = "serde_support")]
 impl<T, const N: usize> Serialize for StaticVec<T, {N}>
 where T: Serialize {
+  #[inline(always)]
   fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
   where S: Serializer {
     serializer.collect_seq(self)
